SelectionSet class

Selection Sets specify the Fields to select from their cooresponding schema type, either directly, or indirectly through FragmentSpreads and InlineFragments.

OperationDefinitions only consist of an optional operation name and a SelectionSet into one of the root OperationTypeDefinitions.

An operation selects the set of information it needs, and will receive exactly that information and nothing more, avoiding over‐fetching and under‐fetching data.

Inheritance
Annotations
  • @immutable

Constructors

SelectionSet(SelectionSetNode? astNode, [TypeDefinition? schemaType, GetExecutableType? getType])
const

Properties

astNode → SelectionSetNode?
final
fields → List<Field>
no setter
fragmentSpreads → List<FragmentSpread>
no setter
getType → GetExecutableType
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
inlineFragments → List<InlineFragment>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaType → TypeDefinition?
final
selections → List<Selection>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object o) → bool
The equality operator.
inherited